@@ -16,9 +16,13 @@
 #  You should have received a copy of the GNU General Public License
 #  along with pytest-qgis.  If not, see <https://www.gnu.org/licenses/>.
 #
+import os
+
 from qgis.core import Qgis
 
 try:
     QGIS_VERSION = Qgis.versionInt()
 except AttributeError:
     QGIS_VERSION = Qgis.QGIS_VERSION_INT
+
+IN_CI = os.environ.get("QGIS_IN_CI")
